const path = require("path");
const reactSvgLoader = require.resolve("react-svg-loader");

const lessRegex = /\.less$/;
const cssRegex = /\.css$/;
const jsRegex = /\.js$/;
const iconPath = "../src/components/Icon";

const getStories = () => {
  return process.argv[4] === '-stories'
    ? [`../${process.argv[5]}`]
    : [
        '../**/*.stories.js',
        '../src/components/**/stories.js',
      ];
};

module.exports = {
  stories: () => getStories(),
  addons: [
    '@storybook/preset-create-react-app',
    '@storybook/addon-a11y',
    '@storybook/addon-knobs',
    '@storybook/addon-actions',
    '@storybook/addon-links',
    '@storybook/addon-controls',
    '@storybook/client-api',
  ],
  webpackFinal: async (config) => {
    config.module.rules.map(rule => {
      if (rule && rule.test.toString().includes("svg")) {
        const ruleIndex = config.module.rules.indexOf(rule);
        config.module.rules.splice(ruleIndex, 1);
      }
    });
    config.module.rules.push({
      test: /\.(png|jpg|gif|svg)$/,
      loader: require.resolve("url-loader"),
      query: {},
      exclude: path.resolve(__dirname, iconPath)
    });

    config.module.rules.push({
      test: lessRegex,
      loaders: [
        require.resolve("style-loader"),
        {
          loader: require.resolve("css-loader"),
          options: {
            importLoaders: 2,
            modules: {
              localIdentName: "[name]__[local]___[hash:base64:5]"
            },
          }
        },
        require.resolve("less-loader")
      ]
    });
    config.module.rules.push({
      test: cssRegex,
      loaders: [
        require.resolve("style-loader"),
        {
          loader: require.resolve("css-loader"),
          options: {
            importLoaders: 2,
          }
        },
      ]
    });
    config.module.rules.push({
      test: jsRegex,
      loaders: [require.resolve("babel-loader")]
    });
    config.module.rules.push({
      test: /\.svg$/,
      use: [
        "babel-loader",
        {
          loader: reactSvgLoader, // 'react-svg'
          query: {
            svgo: {
              pretty: true,
              plugins: [{ removeStyleElement: true }]
            }
          }
        }
      ],
      exclude: path.resolve(__dirname, "../node-modules")
    });
    return config;
  },
};
