import json from '@rollup/plugin-json'
import resolve from 'rollup-plugin-node-resolve'
import babel from 'rollup-plugin-babel'
import commonjs from 'rollup-plugin-commonjs'
import css from 'rollup-plugin-css-porter'
import postcss from 'rollup-plugin-postcss'
import svgr from '@svgr/rollup'
import image from '@rollup/plugin-image'

import pkg from './package.json'

export default {
  input: 'src/index.js',
  output: [
    {
      file: pkg.main,
      format: 'cjs',
    },
    {
      file: pkg.module,
      format: 'es',
    },
  ],
  external: ['react', 'prop-types', 'react-dom', 'react-router-dom'],
  plugins: [
    resolve(),
    json(),
    postcss({
      autoModules: true,
      namedExports: true,
      modules: true,
      inject: false,
      extract: true,
      extensions: ['.less'],
    }),
    css({
      dest: 'dist/externals.css',
    }),
    babel({
      exclude: 'node_modules/**',
    }),
    image({
      exclude: 'src/components/Icons/files/**',
    }),
    svgr({ titleProp: true }),
    commonjs({
      namedExports: {
        'node_modules/react-dates/index.js': ['DateRangePicker'],
      },
    }),
  ],
}
