import React from 'react'
import PropTypes from 'prop-types'
import cn from 'classnames/bind'

import Button, { mobileBreakPoints, buttonTypes } from '../Button'
import Badge from '../Badge'
import Icon, { icons } from '../Icons'
import styles from './assignmentButton.less'

import { useLocalize } from '../../utils/localize'

const cx = cn.bind(styles)

const AssignmentButton = ({
  assignmentCount,
  hideLabelAtBreakPoint,
  onClick,
  disabled,
  isAssigning,
}) => {
  const localizedAssignText = useLocalize`Assign`
  const buttonContentClass = cx(styles.buttonContent, {
    hiddenMd: hideLabelAtBreakPoint === mobileBreakPoints.medium,
    hiddenSm: hideLabelAtBreakPoint === mobileBreakPoints.small,
    hiddenXs: hideLabelAtBreakPoint === mobileBreakPoints.xSmall,
  })
  const buttonProps = {
    onClick,
    buttonClass: styles.buttonClass,
    type: buttonTypes.primary,
    disabled,
    isLoading: isAssigning,
  }
  return (
    <Button {...buttonProps}>
      <div className={styles.pill}>
        {assignmentCount && <Badge badgeText={assignmentCount} badgeClassName={styles.badge} />}
        <Icon icon={icons.ASSIGN} size={20} />
      </div>
      <div className={buttonContentClass}>{localizedAssignText}</div>
    </Button>
  )
}

AssignmentButton.defaultProps = {
  assignmentCount: '',
  hideLabelAtBreakPoint: mobileBreakPoints.medium,
  disabled: false,
  isAssigning: false,
}

AssignmentButton.propTypes = {
  assignmentCount: PropTypes.string,
  hideLabelAtBreakPoint: PropTypes.oneOf(Object.values(mobileBreakPoints)),
  onClick: PropTypes.func.isRequired,
  disabled: PropTypes.bool,
  isAssigning: PropTypes.bool,
}

export default AssignmentButton
