import React from 'react'
import PropTypes from 'prop-types'
import { Link } from 'react-router-dom'
import { useLocalizeAll } from '../../utils/localize'
import InternalLink from '../InternalLink'
import Icon from '../Icons/Icon'
import icons from '../Icons/icons'
import styles from './backToLink.less'
import getDataEventContext from '../../utils/analytics'

const BackToLink = ({ eventContext, to, linkText, useReactRouter, onClick }) => {
  const LinkComponent = useReactRouter ? Link : InternalLink

  return (
    <LinkComponent
      className={styles.linkContainer}
      onClick={onClick}
      to={to}
      {...(useReactRouter && getDataEventContext(eventContext))}
      {...(!useReactRouter && { eventContext })}
    >
      <Icon icon={icons.PREVIOUS} size={18} />
      <span className={styles.linkText}>{useLocalizeAll`${linkText}`}</span>
    </LinkComponent>
  )
}

BackToLink.defaultProps = {
  eventContext: null,
  linkText: 'Back to List',
  onClick: null,
  useReactRouter: true,
}

BackToLink.propTypes = {
  /** Context object used for telemetry analysis */
  eventContext: PropTypes.shape({}),
  /** Where you want to send the user back to */
  to: PropTypes.string.isRequired,
  /** What should the link say? */
  linkText: PropTypes.string,
  /** Are we linking back to a react page? */
  useReactRouter: PropTypes.bool,
  /** Custom onclick handler if needed */
  onClick: PropTypes.func,
}

export default BackToLink
