import React from 'react'
import renderer from 'react-test-renderer'
import Button from './Button'

describe('<Button />', () => {
  it('renders correctly', () => {
    const tree = renderer.create(<Button />).toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('renders correctly when disabled', () => {
    const tree = renderer.create(<Button disabled />).toJSON()
    expect(tree).toMatchSnapshot()
  })

  describe('Given the event context', () => {
    it('should show data-event-context', () => {
      const eventContext = {
        abc: 'abc',
      }
      const container = renderer.create(<Button eventContext={eventContext} />)

      expect(container.root.findByType('button').props['data-event-context']).toStrictEqual(
        '{"abc":"abc"}'
      )
    })

    it('should not show data-event-context', () => {
      const eventContext = {}
      const container = renderer.create(<Button eventContext={eventContext} />)

      expect(container.root.findByType('button').props['data-event-context']).toBeUndefined()
    })
  })
})
