import React from 'react'
// Import the storybook libraries
import { storiesOf } from '@storybook/react'
import { action } from '@storybook/addon-actions'
// Set up interactivity with knobs
import { text, boolean, select, object } from '@storybook/addon-knobs'
// Import our component from this folder
import Button, { buttonTypes, mobileBreakPoints } from './Button'
import { icons } from '../Icons'

const stories = storiesOf('Buttons', module)

const buildDecorators = () => {
  const iconArray = Object.keys(icons)
  const mobileSizes = Object.keys(mobileBreakPoints)
  const buttonText = () => text('Button Text:', 'Button Text')
  const ariaLabel = () => text('Aria Label:', 'Button Text')
  const isLoading = () => boolean('Loading State:', false)
  const isDisabled = () => boolean('Disabled:', false)
  const isLink = () => boolean('Link Button:', false)
  const hideLabelAtBreakPoint = () => select('Hide at breakpoint:', mobileSizes, 'medium')
  const eventLabel = () => text('Event Label:', null)
  const eventContext = () => object('Event Context:', null)
  const showIcons = () => boolean('Show Icon:', false)
  const buttonIcon = () => select('Left Icon:', iconArray, 'LABEL')
  const showIconRight = () => boolean('Show Icon Right:', false)
  const buttonIconRight = () => select('Right Icon:', iconArray, 'NEXT')

  const sharedButtonProps = {
    ariaLabel: ariaLabel(),
    asLink: isLink(),
    buttonIcon: showIcons() ? icons[buttonIcon()] : null,
    buttonIconRight: showIconRight() ? icons[buttonIconRight()] : null,
    buttonText: buttonText(),
    disabled: isDisabled(),
    eventContext: eventContext(),
    eventLabel: eventLabel(),
    extraButtonProps: isLink() && { href: 'http://google.com', target: '_blank' },
    hideLabelAtBreakPoint: mobileBreakPoints[hideLabelAtBreakPoint()],
    isLoading: isLoading(),
    onClick: action('clicked'),
    shouldLocalize: true,
  }
  return sharedButtonProps
}
stories
  .add('Primary', () => {
    const sharedButtonProps = buildDecorators()
    return <Button {...sharedButtonProps} />
  })
  .add('Secondary', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.secondary} {...sharedButtonProps} />
  })
  .add('Info', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.info} {...sharedButtonProps} />
  })
  .add('Info New', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.infoNew} {...sharedButtonProps} />
  })
  .add('Danger', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.danger} {...sharedButtonProps} />
  })
  .add('Success', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.success} {...sharedButtonProps} />
  })
  .add('Complete', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.complete} {...sharedButtonProps} />
  })
  .add('Editable New', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.editableNew} {...sharedButtonProps} />
  })
  .add('Editable', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.editable} {...sharedButtonProps} />
  })
  .add('Link', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.link} {...sharedButtonProps} />
  })
  .add('Danger Link', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.dangerLink} {...sharedButtonProps} />
  })
  .add('Info Link', () => {
    const sharedButtonProps = buildDecorators()
    return <Button type={buttonTypes.infoLink} {...sharedButtonProps} />
  })
