import React from 'react'
import { render, unmountComponentAtNode } from 'react-dom'
import { act } from 'react-dom/test-utils'
import renderer from 'react-test-renderer'
import Checkbox from './Checkbox'

describe('<Checkbox />', () => {
  it('renders default correctly', () => {
    const tree = renderer.create(<Checkbox id="checkbox-id" label="the-label" />).toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('renders large state correctly', () => {
    const tree = renderer.create(<Checkbox id="checkbox-id" label="the-label" large />).toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('renders checked state correctly', () => {
    const tree = renderer.create(<Checkbox id="checkbox-id" label="the-label" isChecked />).toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('renders disabled state correctly', () => {
    const tree = renderer.create(<Checkbox id="checkbox-id" label="the-label" disabled />).toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('renders indeterminate state correctly', () => {
    // must render in document to check the input element's indeterminate property
    let container = document.createElement('div')
    document.body.appendChild(container)

    act(() => {
      render(<Checkbox id="checkbox-id" label="the-label" indeterminate />, container)
    })
    expect(document.querySelector('input').indeterminate).toBe(true)

    unmountComponentAtNode(container)
    container.remove()
    container = null
  })
})
