import React from 'react'
import { useArgs } from '@storybook/client-api'
import DateRangePicker from './DateRangePicker'
import { formatDate, isValidDate } from '../../utils/date'

export default {
  title: 'Accessible Date Range Picker',
  component: DateRangePicker,
  argTypes: {
    maxDate: { control: 'date' },
    minDate: { control: 'date' },
    startDateValue: { control: 'date' },
    endDateValue: { control: 'date' },
  },
}

export const DateRangePickerComponent = ({ ...args }) => {
  const [{ startDateValue, endDateValue }, updateArgs] = useArgs()

  const handleChange = ({ startDate, endDate }) => {
    updateArgs({ startDateValue: startDate, endDateValue: endDate })
  }

  return (
    <div data-notranslate>
      <DateRangePicker onChange={handleChange} {...args} />
      <p>Start Date: {isValidDate(startDateValue) ? formatDate(startDateValue) : ''}</p>
      <p>End Date: {isValidDate(endDateValue) ? formatDate(endDateValue) : ''}</p>
    </div>
  )
}

DateRangePickerComponent.args = {
  minDate: '',
  maxDate: '',
  startDateValue: '',
  endDateValue: '',
}
