import React from 'react'
import classNames from 'classnames'
import styles from './errorMessage.less'
import { errorMessageDefaultShape, errorMessageShape } from '../../propTypes/formShapes'

const ErrorMessage = ({ message, id, label }) => {
  const messageIsFunction = typeof message === 'function'
  const errorClass = classNames(styles.errorMessage, {
    [styles.center]: !messageIsFunction,
    [styles.hidden]: message === null,
  })
  return !message ? null : (
    <div className={errorClass}>
      <div className={styles.redCircle}>
        <span>!</span>
      </div>
      <span aria-live="assertive" role="alert" id={`${id}-error`} className={styles.message}>
        {messageIsFunction ? message({ label }) : message}
      </span>
    </div>
  )
}

ErrorMessage.defaultProps = errorMessageDefaultShape

ErrorMessage.propTypes = errorMessageShape

export default ErrorMessage
