import React from 'react'
import renderer from 'react-test-renderer'
import Chance from 'chance'
import LabelValue from './LabelValue'
import Label from '../Label'

const chance = Chance()

describe('<LabelValue />', () => {
  const getRequireProps = override => ({
    forId: chance.hash(),
    formElement: <div data-testid="test">hello world</div>,
    labelProps: {
      label: chance.string(),
    },
    ...override,
  })

  it('show match snapshot', () => {
    const props = getRequireProps({
      forId: 'some-id',
      formElement: 'some-value',
      labelProps: {
        label: 'some-label',
      },
      errorMessage: 'some-error',
    })
    const testRenderer = renderer.create(<LabelValue {...props} />).toJSON()

    expect(testRenderer).toMatchSnapshot()
  })

  it('should pass optional props', () => {
    const props = getRequireProps({
      className: chance.hash(),
      errorMessage: chance.string(),
      labelProps: {
        className: chance.hash(),
        isRequired: chance.bool(),
        label: chance.string(),
      },
    })
    const testRenderer = renderer.create(<LabelValue {...props} />).root
    const label = testRenderer.findByType(Label)
    const error = testRenderer.findByProps({ id: `${props.forId}-error` })

    expect(testRenderer.props.className.includes(props.className)).toBeTruthy()
    expect(label.props.required).toStrictEqual(props.labelProps.isRequired)
    expect(label.props.className).toStrictEqual(props.labelProps.className)
    expect(error.props.children).toStrictEqual(props.errorMessage)
  })

  it('show a label', () => {
    const props = getRequireProps()
    const testRenderer = renderer.create(<LabelValue {...props} />)
    const testInstance = testRenderer.root

    expect(testInstance.findByType('label').children.includes(props.labelProps.label)).toBeTruthy()
    expect(testInstance.findByType('label').props.htmlFor).toStrictEqual(props.forId)
  })

  it('show a value', () => {
    const props = getRequireProps()
    const testRenderer = renderer.create(<LabelValue {...props} />)
    const testInstance = testRenderer.root

    expect(testInstance.findByProps({ 'data-testid': 'test' }).props.children).toStrictEqual(
      'hello world'
    )
  })
})
