import React from 'react'
import PropTypes from 'prop-types'
import TextInput from '../TextInput'
import LabelValue from './LabelValue'

const TextInputFormGroup = ({ className, errorMessage, forId, inputProps, labelProps }) => (
  <LabelValue
    className={className}
    errorMessage={errorMessage}
    forId={forId}
    formElement={<TextInput {...inputProps} id={forId} />}
    labelProps={labelProps}
  />
)

TextInputFormGroup.defaultProps = {
  className: null,
  errorMessage: null,
  labelProps: {
    className: null,
    isRequired: false,
  },
}

TextInputFormGroup.propTypes = {
  /** extra class pass to the component */
  className: PropTypes.string,
  /** display error if there are any */
  errorMessage: PropTypes.string,
  /** Identifier for accessibility with label + input */
  forId: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
  /** properties pass to text input */
  inputProps: PropTypes.shape({
    /** call back function */
    onChange: PropTypes.func.isRequired,
    /** display value for input */
    value: PropTypes.string.isRequired,
  }).isRequired,
  /** properties passes to label */
  labelProps: PropTypes.shape({
    /** extra class pass to the component */
    className: PropTypes.string,
    /** Indicator to add asterisk to label */
    isRequired: PropTypes.bool,
    /** display value for label */
    label: PropTypes.string.isRequired,
  }),
}

export default TextInputFormGroup
