import React from 'react'
import renderer from 'react-test-renderer'
import Chance from 'chance'
import TextInputFormGroup from './TextInputFormGroup'

const chance = Chance()

describe('<TextInputFormGroup />', () => {
  const getRequireProps = override => ({
    forId: chance.hash(),
    inputProps: {
      onChange: jest.fn(),
      value: chance.string(),
    },
    labelProps: {
      label: chance.string(),
    },
    ...override,
  })

  it('show match snapshot', () => {
    const props = getRequireProps({
      forId: 'some-id',
      inputProps: {
        onChange: jest.fn(),
        value: 'some-value',
      },
      labelProps: {
        label: 'some-label',
      },
    })
    const testRenderer = renderer.create(<TextInputFormGroup {...props} />).toJSON()

    expect(testRenderer).toMatchSnapshot()
  })

  it('should pass optional props', () => {
    const props = getRequireProps({
      className: chance.string(),
      errorMessage: chance.string(),
      labelProps: {
        className: chance.hash(),
        isRequired: chance.bool(),
        label: chance.hash(),
      },
    })
    const testRenderer = renderer.create(<TextInputFormGroup {...props} />).root

    expect(testRenderer.props.className).toStrictEqual(props.className)
    expect(testRenderer.props.labelProps).toStrictEqual(props.labelProps)
    expect(testRenderer.props.errorMessage).toStrictEqual(props.errorMessage)
  })

  it('show a label', () => {
    const props = getRequireProps()
    const testRenderer = renderer.create(<TextInputFormGroup {...props} />)
    const testInstance = testRenderer.root

    expect(testInstance.findByType('label').children.includes(props.labelProps.label)).toBeTruthy()
  })

  it('show a text input', () => {
    const props = getRequireProps()
    const testRenderer = renderer.create(<TextInputFormGroup {...props} />)
    const testInstance = testRenderer.root

    expect(testInstance.findByType('input').props.value).toStrictEqual(props.inputProps.value)
    expect(testInstance.findByType('input').props.id).toStrictEqual(props.forId)
  })

  describe('when the input is change', () => {
    it('should trigger the callback', () => {
      const props = getRequireProps()
      const testRenderer = renderer.create(<TextInputFormGroup {...props} />)
      const testInstance = testRenderer.root
      const event = {
        target: { value: chance.string() },
      }

      testInstance.props.inputProps.onChange(event)

      expect(props.inputProps.onChange).toHaveBeenCalledTimes(1)
      expect(props.inputProps.onChange).toHaveBeenCalledWith(event)
    })
  })
})
