import React from 'react'
import PropTypes from 'prop-types'
import icons from './icons'

const Icon = ({ circleClassName, className, icon, insideCircle, size, style, title, viewBox }) => {
  const circleSize = `${size + size * 0.5}px`
  const innerCircleIconStyle = {
    fill: 'white',
    pointerEvents: 'none',
    position: 'relative',
    zIndex: 10,
  }
  const Svg = icon
  const iconName = Object.entries(icons).find(value => value[1] === icon)[0]

  const svgIcon = (
    <Svg
      width={`${size}px`}
      height={`${size}px`}
      style={insideCircle ? { ...innerCircleIconStyle } : { ...style, pointerEvents: 'none' }}
      className={className}
      viewBox={viewBox}
      role="img"
      title={title ?? `${iconName} ICON`}
    />
  )
  const circleIcon = (
    <div
      style={{
        width: circleSize,
        height: circleSize,
        display: 'inline-flex',
        justifyContent: 'center',
        alignItems: 'center',
        position: 'relative',
      }}
    >
      {svgIcon}
      <icons.CIRCLE
        width={circleSize}
        height={circleSize}
        style={{ position: 'absolute', left: 0, ...style }}
        className={circleClassName}
        viewBox={viewBox}
        title="CIRCLE ICON"
        role="img"
      />
    </div>
  )
  if (insideCircle) return circleIcon

  return svgIcon
}

Icon.defaultProps = {
  circleClassName: '',
  className: '',
  insideCircle: false,
  size: 24,
  style: {},
  title: null,
  viewBox: '0 0 1024 1024',
}

Icon.propTypes = {
  /** The class for the circle */
  circleClassName: PropTypes.string,
  /** SVG class name */
  className: PropTypes.string,
  /** A SVG path string from icons.js */
  icon: PropTypes.func.isRequired,
  /** Do you want the icon in a circle? */
  insideCircle: PropTypes.bool,
  /** The width and height in pixels */
  size: PropTypes.number,
  /** SVG style */
  style: PropTypes.shape({}),
  /** Optional title for accessibility - defaults to icon name */
  title: PropTypes.string,
  /** The SVG viewbox */
  viewBox: PropTypes.string,
}

export default Icon
