import React from 'react'
import PropTypes from 'prop-types'
import Icon, { icons } from '../Icons'
import InternalLink from '../InternalLink'
import { useLocalizeAll } from '../../utils/localize'
import styles from './infoBanner.less'

export const infoBannerTypes = {
  danger: styles.isDangerBanner,
  info: styles.isInfoBanner,
  success: styles.isSuccessBanner,
  warning: styles.isWarningBanner,
}

const InfoBanner = ({ children, header, message, linkText, link, shouldLocalize, type }) => {
  const headerText = useLocalizeAll`${header}`
  const messageText = useLocalizeAll`${message}`

  const getBannerIcon = bannerType => {
    // TODO: update this lookup with approved icons for each type
    switch (bannerType) {
      case infoBannerTypes.info:
        return icons.INFO
      case infoBannerTypes.danger:
        return icons.WARNING
      case infoBannerTypes.success:
        return icons.CHECK
      case infoBannerTypes.warning:
        return icons.WARNING
      default:
        return icons.WARNING
    }
  }

  return (
    <div className={type}>
      <div className={styles.colorBar} />
      <Icon icon={getBannerIcon(type)} size={20} />
      <div className={styles.content}>
        <div className={styles.text}>
          <strong>{shouldLocalize ? headerText : header}</strong>
          {children || <p>{shouldLocalize ? messageText : message}</p>}
          {link && (
            <InternalLink
              className={type}
              linkText={linkText}
              to={link}
              shouldLocalize={shouldLocalize}
            />
          )}
        </div>
      </div>
    </div>
  )
}

InfoBanner.defaultProps = {
  children: null,
  header: null,
  link: null,
  linkText: null,
  message: null,
  shouldLocalize: true,
  type: infoBannerTypes.warning, // TODO: change default type to info when supported colors get added
}

InfoBanner.propTypes = {
  children: PropTypes.node,
  header: PropTypes.string,
  link: PropTypes.string,
  linkText: PropTypes.string,
  message: PropTypes.string,
  shouldLocalize: PropTypes.bool,
  type: PropTypes.oneOf(Object.values(infoBannerTypes)),
}

export default InfoBanner
