import React from 'react'
import renderer from 'react-test-renderer'
import InfoBanner, { infoBannerTypes } from './InfoBanner'

describe('<InfoBanner />', () => {
  it('renders default correctly', () => {
    const tree = renderer
      .create(
        <InfoBanner
          header="Testing"
          link="www.google.com"
          linkText="yippee"
          message="Warning message"
        />
      )
      .toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('renders info type correctly', () => {
    const tree = renderer
      .create(
        <InfoBanner
          type={infoBannerTypes.info}
          header="Testing"
          message="Warning message"
          linkText="yippee"
          link="www.google.com"
        />
      )
      .toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('renders warning type correctly', () => {
    const tree = renderer
      .create(
        <InfoBanner
          type={infoBannerTypes.warning}
          header="Testing"
          message="Warning message"
          linkText="yippee"
          link="www.google.com"
        />
      )
      .toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('renders danger type correctly', () => {
    const tree = renderer
      .create(
        <InfoBanner
          type={infoBannerTypes.danger}
          header="Testing"
          message="Warning message"
          linkText="yippee"
          link="www.google.com"
        />
      )
      .toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('renders success type correctly', () => {
    const tree = renderer
      .create(
        <InfoBanner
          type={infoBannerTypes.success}
          header="Testing"
          message="Warning message"
          linkText="yippee"
          link="www.google.com"
        />
      )
      .toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('should match snapshot when props is not defined', () => {
    const tree = renderer.create(<InfoBanner />).toJSON()
    expect(tree).toMatchSnapshot()
  })

  it('should show the children element in place of message', () => {
    const randomString = 'my-random-string'
    const props = {
      children: <div data-testid="child-element">{randomString}</div>,
      message: 'message;',
    }
    const testRenderer = renderer.create(<InfoBanner {...props} />)
    const testInstance = testRenderer.root

    expect(
      testInstance.findByProps({ 'data-testid': 'child-element' }).props.children
    ).toStrictEqual(randomString)
    expect(testRenderer.toJSON()).toMatchSnapshot()
  })
})
