import React from 'react'
import renderer from 'react-test-renderer'
import InternalLink from './InternalLink'

describe('<InternalLink />', () => {
  it('renders correctly', () => {
    const tree = renderer
      .create(<InternalLink to="./?path=/story/links--internal-link" useReactRouter={false} />)
      .toJSON()
    expect(tree).toMatchSnapshot()
  })

  describe('Given the event context', () => {
    describe('and the link is not react router', () => {
      it('should show data-event-context', () => {
        const eventContext = {
          abc: 'abc',
        }
        const container = renderer.create(<InternalLink eventContext={eventContext} />)

        expect(container.root.findByType('a').props['data-event-context']).toStrictEqual(
          '{"abc":"abc"}'
        )
      })

      it('should not show data-event-context', () => {
        const eventContext = {}
        const container = renderer.create(<InternalLink eventContext={eventContext} />)

        expect(container.root.findByType('a').props['data-event-context']).toBeUndefined()
      })
    })
  })
})
