import React from 'react'
import cx from 'classnames'
import PropTypes from 'prop-types'
import { useLocalizeAll } from '../../utils/localize'
import styles from './label.less'

const Label = ({
  id,
  required,
  className,
  label,
  forId,
  formGroupHeading,
  inline,
  isLegend,
  shouldLocalize,
  title,
}) => {
  const classes = cx(className, {
    [styles.formGroupHeading]: formGroupHeading,
    [styles.label]: !className,
    [styles.inline]: inline,
  })
  const LabelComponent = isLegend ? 'legend' : 'label'
  const localizedLabel = useLocalizeAll`${label}`
  return (
    <LabelComponent id={id} htmlFor={forId} className={classes} title={title}>
      {shouldLocalize ? localizedLabel : label}
      {required && <span className={styles.required}>*</span>}
    </LabelComponent>
  )
}

export default Label

Label.defaultProps = {
  label: '',
  required: false,
  className: null,
  formGroupHeading: false,
  forId: null,
  inline: false,
  shouldLocalize: false,
  title: null,
  id: null,
  isLegend: false,
}

Label.propTypes = {
  /** Contents label to input */
  forId: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  /** The node that this labels */
  label: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  /** Is it required? */
  required: PropTypes.bool,
  /** Custom class for Label */
  className: PropTypes.string,
  /** Style used for fieldset > legend */
  formGroupHeading: PropTypes.bool,
  /** Is this display inline */
  inline: PropTypes.bool,
  /** Defaults to false, shouldLocalize all non-user entered labels */
  shouldLocalize: PropTypes.bool,
  /** The input of the label or legend */
  id: PropTypes.string,
  /** The title of the label or legend */
  title: PropTypes.string,
  /** Should it be a legend element */
  isLegend: PropTypes.bool,
}
