import React from 'react'
import PropTypes from 'prop-types'
import cn from 'classnames/bind'
import styles from './loadingSpinner.less'

export const SPINNER_TYPES = {
  xs: 'xs',
  small: 'small',
  medium: 'medium',
  large: 'large',
}
const SPINNER_SIZES = {
  xs: 16,
  small: 32,
  medium: 52,
  large: 72,
}

const STROKE_WIDTHS = {
  xs: 2,
  small: 3,
  medium: 4,
  large: 5,
}

const cx = cn.bind(styles)

/**
 * A loading spinner component based on https://jsfiddle.net/codylg/v8670mj6/
 */
const LoadingSpinner = ({ size, color }) => {
  const baseSize = SPINNER_SIZES[size]
  const pathSize = baseSize / 2
  const strokeWidth = STROKE_WIDTHS[size]
  const pathRadius = `${baseSize / 2 - strokeWidth}px`
  const containerClassName = cx(styles[size])
  const spinnerModifier = `spinner-${size}`
  const spinnerClassName = `${cx(styles.spinner)} ${cx(styles[spinnerModifier])}`
  const spinnerStyle = color ? { stroke: color } : {}
  return (
    <div className={containerClassName}>
      <svg
        viewBox={`0 0 ${baseSize} ${baseSize}`}
        width={baseSize}
        height={baseSize}
        role="img"
        aria-label="loading"
      >
        <title>Loading</title>
        <desc>An animated circle used as a loading indicator</desc>
        <circle
          className={spinnerClassName}
          strokeWidth={strokeWidth}
          style={spinnerStyle}
          cx={pathSize}
          cy={pathSize}
          r={pathRadius}
          fill="none"
        />
      </svg>
    </div>
  )
}

LoadingSpinner.defaultProps = {
  size: 'small',
  color: null,
}

LoadingSpinner.propTypes = {
  /** variation of the spinner. small and medium can be used anywhere, large should be used in the app level. */
  size: PropTypes.oneOf(['xs', 'small', 'medium', 'large']),
  /** Color over ride if you don't want an orange spinner */
  color: PropTypes.string,
}

export default LoadingSpinner
