import isString from 'lodash/isString'
import React from 'react'
import PropTypes from 'prop-types'
import { useLocalizeAll } from '../../utils/localize'
import { useStopDocumentScroll } from '../../utils/dom'
import logoSpinner from './loading.gif'
import styles from './loadingUIBlocker.less'

const LoadingUIBlockerHooks = ({ message }) => {
  useStopDocumentScroll()
  const messageString = isString(message) ? message : ''
  const localizedMessage = useLocalizeAll`${messageString}`
  return (
    <div className={styles.uiBlockContainer}>
      <img src={logoSpinner} width="65px" alt="animated logo" />
      <div className={styles.messageContainer}>
        {isString(message) ? localizedMessage : message()}
      </div>
    </div>
  )
}

LoadingUIBlockerHooks.propTypes = {
  /** The message to display to the user, this will localize automatically if just a string */
  message: PropTypes.oneOfType([PropTypes.func, PropTypes.string]).isRequired,
}

const LoadingUIBlocker = props => <LoadingUIBlockerHooks {...props} />

export default LoadingUIBlocker
