import React, { useState, useEffect } from 'react'
import Dropdown from '../Dropdown'
import styles from './localizeWidget.less'
import Icon, { icons } from '../Icons'

const LocalizeWidgetHooks = () => {
  const localizeIsReady = window.Localize && window.Localize.loaded
  const initialLanguage = localizeIsReady ? window.Localize.getLanguage() : 'en'
  const [availableLanguages, setAvailableLanguages] = useState(null)
  const [currentLanguage, setCurrentLanguage] = useState(initialLanguage)

  useEffect(() => {
    const updateLanguage = language => {
      setCurrentLanguage(language.to)
    }
    if (localizeIsReady) window.Localize.on('setLanguage', updateLanguage)
    return () => {
      if (localizeIsReady) window.Localize.off('setLanguage', updateLanguage)
    }
  }, [currentLanguage, localizeIsReady])

  if (localizeIsReady)
    window.Localize.getAvailableLanguages((err, languages) => {
      if (!availableLanguages) setAvailableLanguages(languages)
    })

  if (availableLanguages && localizeIsReady) {
    const dropdownLabel = availableLanguages.find(language => language.code === currentLanguage)
      .name
    const labelComponent = (
      <span className={styles.localizeButton} role="textbox" aria-label={dropdownLabel}>
        <Icon icon={icons.LOCALIZE} size={20} />
        {dropdownLabel}
      </span>
    )
    return (
      <Dropdown labelComponent={labelComponent} className={styles.localizeContainer}>
        {availableLanguages.map(language => (
          <button
            key={language.code}
            type="button"
            onClick={() => window.Localize.setLanguage(language.code)}
            role="menuitem"
          >
            {language.name}
          </button>
        ))}
      </Dropdown>
    )
  }

  return null
}

const LocalizeWidget = () => {
  return <LocalizeWidgetHooks />
}

export default LocalizeWidget
