import React from 'react'
import renderer from 'react-test-renderer'
import Chance from 'chance'
import Cleave from 'cleave.js/react'

import { maskConfiguration, MaskInput } from '../index'

const chance = Chance()

describe('<MaskInput/>', () => {
  const getRequireProps = override => ({ ...override })
  const render = (props = getRequireProps()) => renderer.create(<MaskInput {...props} />)

  test('should show the mask input', () => {
    const wrapper = render().toJSON()

    expect(wrapper).toMatchSnapshot()
  })

  test('should match snapshot', () => {
    expect(maskConfiguration).toMatchSnapshot()
  })

  describe('when there are props passed', () => {
    test('should show the mask input', () => {
      const props = getRequireProps({
        containerClass: chance.hash(),
        id: chance.hash(),
        inputClass: chance.hash(),
        placeholder: chance.string(),
        required: chance.bool(),
        value: chance.string(),
      })
      const wrapper = render(props).root
      const cleaveComponent = wrapper.findByType(Cleave)

      expect(wrapper.findByType('div').props.className).toStrictEqual(
        `inputContainer ${props.containerClass}`
      )
      expect(cleaveComponent.props.className).toStrictEqual(`inputClass ${props.inputClass}`)
      expect(cleaveComponent.props['aria-required']).toStrictEqual(props.required)
      expect(cleaveComponent.props.placeholder).toStrictEqual(props.placeholder)
      expect(cleaveComponent.props.required).toStrictEqual(props.required)
      expect(cleaveComponent.props.value).toStrictEqual(props.value)
    })

    test('should proper set disable style', () => {
      const props = getRequireProps({
        disabled: true,
        hasError: true,
      })
      const wrapper = render(props).root.findByType(Cleave)

      expect(wrapper.props.className).toStrictEqual(`inputClass disabled`)
    })

    test('should proper set error style when disabled is false', () => {
      const props = getRequireProps({
        disabled: false,
        hasError: true,
      })
      const wrapper = render(props).root.findByType(Cleave)

      expect(wrapper.props.className).toStrictEqual(`inputClass inputError`)
    })
  })
})
