import React, { useEffect, useState } from 'react'
// Import the storybook libraries
import { storiesOf } from '@storybook/react'
import { action } from '@storybook/addon-actions'
import { text, boolean, select, object } from '@storybook/addon-knobs'

// Import our component from this folder
import { MaskInput, Label, maskConfiguration } from '../index'

const stories = storiesOf('Form Elements', module)

const NO_DEFINED_MASK_CONFIGURATION = 'None'
const disabled = () => boolean('Disabled:', false)
const hasError = () => boolean('Has error:', false)
const placeholder = () => text('Placeholder:', '')
const containerClass = () => text('Container Class:', '')
const value = () => text('Input Value:', undefined)
const describedBy = () => text('Aria-described by id:', undefined)
const inputClass = () => text('Input Class:', '')
const type = () =>
  select(
    'Input types',
    {
      undefined,
      email: 'email',
      password: 'password',
      search: 'search',
      tel: 'tel',
      text: 'text',
      week: 'week',
    },
    undefined
  )
const maskingProps = () => object('Custom mask object', {})
const initState = { value: '', rawValue: '' }
const maskType = () =>
  select('Type of Mask:', [NO_DEFINED_MASK_CONFIGURATION, ...Object.keys(maskConfiguration)], 'EIN')
stories.add('Masking Input', () => {
  const [state, setState] = useState(initState)
  const mask = maskType()
  const masking = maskingProps()
  const [maskProps, setMaskProps] = useState(maskConfiguration[mask])
  const [isSettingMask, setIsSettingMask] = useState(false)
  useEffect(() => {
    const handleMaskUpdate = async () => {
      await setIsSettingMask(true)
      await setMaskProps(maskConfiguration[mask] || masking)
      await setState(initState)
      setIsSettingMask(false)
    }
    handleMaskUpdate()
  }, [mask, masking])

  const example = '{"creditCard": true}'
  return (
    <section>
      <Label label="Masking Input" forId="masking" />
      {!isSettingMask && (
        <MaskInput
          containerClass={containerClass()}
          describedBy={describedBy()}
          disabled={disabled()}
          hasError={hasError()}
          id="masking"
          inputClass={inputClass()}
          onChange={event => {
            action('onChange')
            setState({
              value: event.target.value,
              rawValue: event.target.rawValue,
            })
          }}
          maskProps={maskProps}
          placeholder={placeholder()}
          type={type()}
          value={value()}
        />
      )}
      {mask.includes(NO_DEFINED_MASK_CONFIGURATION) && (
        <>
          How to use custom mask
          <ul>
            <li>
              To apply custom masking you need to put in a valid json in `Custom mask object`
              <pre>{JSON.stringify(example, null, 4)}</pre>
            </li>
          </ul>
        </>
      )}
      Masking configuration: <pre>{JSON.stringify(maskProps, null, 4)}</pre>
      Event Value: <pre>{JSON.stringify(state)}</pre>
    </section>
  )
})
