import React from 'react'
import PropTypes from 'prop-types'
import Button from '../Button'
import Icon, { icons } from '../Icons'
import Modal from '../Modal'
import styles from './modalIcon.less'
import { useModal } from '../Modal/Modal'

const ModalIcon = ({
  icon,
  iconSize,
  iconClassName,
  title,
  children,
  modalClassName,
  extraIconProps,
  extraModalProps,
  shouldHaveCloseButton,
}) => {
  const { isShowing, toggleModal } = useModal()

  return (
    <>
      <button className={styles.iconWrapper} type="button" title={title} onClick={toggleModal}>
        <Icon icon={icon} size={iconSize} className={iconClassName} {...extraIconProps} />
      </button>
      {isShowing && (
        <Modal
          onClose={toggleModal}
          className={modalClassName}
          enableCloseButton={!shouldHaveCloseButton}
          {...extraModalProps}
        >
          {children}
          {shouldHaveCloseButton && (
            <div className={styles.closeButtonDiv}>
              <Button onClick={toggleModal} buttonText="Close" />
            </div>
          )}
        </Modal>
      )}
    </>
  )
}

ModalIcon.defaultProps = {
  icon: icons.MAYBE,
  iconSize: 20,
  iconClassName: '',
  modalClassName: '',
  extraIconProps: {},
  extraModalProps: {},
  shouldHaveCloseButton: false,
  title: 'Show more information',
}

ModalIcon.propTypes = {
  /** The component to render inside the modal. */
  children: PropTypes.oneOfType([PropTypes.func, PropTypes.element]).isRequired,
  /** The icon to render (from our supported icons) */
  icon: PropTypes.func,
  /** Should the modal include a close button? */
  shouldHaveCloseButton: PropTypes.bool,
  /** The icon size in pixels */
  iconSize: PropTypes.number,
  /** Icon class names for styling */
  iconClassName: PropTypes.string,
  /** Modal class names for styling */
  modalClassName: PropTypes.string,
  /** Optional props to pass to the Modal component */
  extraModalProps: PropTypes.shape({
    modalBodyClassName: PropTypes.string,
    fullscreen: PropTypes.bool,
    showBackdrop: PropTypes.bool,
    style: PropTypes.shape(),
    icon: PropTypes.func,
    warn: PropTypes.bool,
    focusFirst: PropTypes.bool,
    focusLast: PropTypes.bool,
    modalClassName: PropTypes.string,
  }),
  /** Optional props to pass to the Icon component */
  extraIconProps: PropTypes.shape({
    style: PropTypes.shape({}),
    viewBox: PropTypes.string,
    insideCircle: PropTypes.bool,
    circleClassName: PropTypes.string,
  }),
  /** Optional prop to make the modal button accessible, default button title is Show more information */
  title: PropTypes.string,
}

export default ModalIcon
