import React from 'react'
import PropTypes from 'prop-types'
import classNames from 'classnames'
import Icon from '../Icons'
import ICONS from '../Icons/icons'
import { inputShape, inputDefaultProps } from '../../propTypes/formShapes'
import styles from './nativeSelect.less'

const NativeSelect = ({
  id,
  containerClass,
  error,
  value,
  onChange,
  options,
  disabled,
  placeholder,
  small,
  inline,
  inputGroupFirst,
  inputGroupLast,
}) => {
  const inputClasses = classNames('', {
    [styles.inputError]: !disabled && error,
    [styles.disabled]: disabled,
    [styles.inputGroupFirst]: inputGroupFirst,
    [styles.inputGroupLast]: inputGroupLast,
    [styles.smallSelect]: small,
    [styles.select]: !small,
  })
  return (
    <div style={{ display: inline ? 'inline-block' : '' }}>
      <div className={styles.inputContainer || containerClass}>
        <select
          id={id}
          className={inputClasses}
          disabled={disabled}
          onChange={onChange}
          value={value}
        >
          {placeholder && (
            <option value="" disabled selected hidden>
              {placeholder}
            </option>
          )}
          {options.map(o => (
            <option key={o} value={o}>
              {o}
            </option>
          ))}
        </select>
        <Icon icon={ICONS.DROPDOWN_DOWN} size={15} className={styles.dropdownArrow} />
      </div>
    </div>
  )
}

NativeSelect.defaultProps = {
  ...inputDefaultProps,
  small: false,
}
NativeSelect.propTypes = {
  ...inputShape,
  /** List of options to choose from */
  options: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.number])).isRequired,
  /** Is the input small sized? */
  small: PropTypes.bool,
}

export default NativeSelect
