import cn from 'classnames/bind'
import PropTypes from 'prop-types'
import React from 'react'
import Phone from 'react-phone-number-input'
import 'react-phone-number-input/style.css'
import styles from './phoneInput.less'

const cx = cn.bind(styles)

const PhoneInput = ({
  ariaDescribedBy,
  ariaLabelledBy,
  country,
  defaultCountry,
  disabled,
  error,
  id,
  name,
  onBlur,
  onChange,
  onFocus,
  phoneInputStyle,
  value,
}) => (
  <div className={cx(styles.phoneInputContainer, { [styles.error]: error })}>
    <Phone
      aria-describedby={ariaDescribedBy}
      aria-labelledby={ariaLabelledBy}
      className={cx({ [styles.disabled]: disabled })}
      country={country}
      defaultCountry={defaultCountry}
      disabled={disabled}
      error={error}
      id={id}
      name={name}
      onBlur={onBlur}
      onChange={disabled ? () => null : onChange}
      onFocus={onFocus}
      style={phoneInputStyle}
      value={value}
    />
  </div>
)

PhoneInput.defaultProps = {
  ariaDescribedBy: undefined,
  ariaLabelledBy: undefined,
  country: 'US',
  defaultCountry: 'US',
  disabled: false,
  error: undefined,
  id: null,
  name: undefined,
  onBlur: null,
  onChange: value => value,
  onFocus: null,
  phoneInputStyle: {},
  value: undefined,
}

PhoneInput.propTypes = {
  ariaDescribedBy: PropTypes.string,
  ariaLabelledBy: PropTypes.string,
  country: PropTypes.string,
  defaultCountry: PropTypes.string,
  disabled: PropTypes.bool,
  error: PropTypes.oneOfType([PropTypes.string, PropTypes.func, PropTypes.bool]),
  id: PropTypes.string,
  name: PropTypes.string,
  onBlur: PropTypes.func,
  onChange: PropTypes.func,
  onFocus: PropTypes.func,
  phoneInputStyle: PropTypes.shape({}),
  value: PropTypes.string,
}

export default PhoneInput
