import React from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import styles from './radioButton.less'
import Label from '../Label'

const RadioButton = ({
  big,
  className,
  disabled,
  id,
  inline,
  isChecked,
  label,
  name,
  onChange,
  required,
  tabIndex,
  value,
  ...rest
}) => (
  <div className={cx(className, { [styles.defaultContainer]: !className })}>
    <input
      aria-checked={isChecked}
      checked={isChecked}
      className={cx(styles.radioInput, { [styles.disabled]: disabled })}
      disabled={disabled}
      id={id}
      name={name}
      onChange={onChange}
      type="radio"
      value={value}
      {...rest}
    />
    {label && <Label forId={id} formGroupHeading={big} inline label={label} required={required} />}
  </div>
)

RadioButton.defaultProps = {
  big: false,
  className: '',
  disabled: false,
  inline: false,
  isChecked: false,
  label: '',
  name: undefined,
  onChange: () => {},
  required: false,
  tabIndex: undefined,
  value: undefined,
}

RadioButton.propTypes = {
  /** The label on the input. */
  label: PropTypes.string,
  /** The value of the input. */
  value: PropTypes.string,
  /** Name of input. */
  name: PropTypes.string,
  /** Called when changed. */
  onChange: PropTypes.func,
  /** The id of the input. */
  id: PropTypes.string.isRequired,
  /**  Attribute on input (is selected) */
  isChecked: PropTypes.bool,
  /** Custom ClassName for radioButton */
  className: PropTypes.string,
  /** Is the input *required? */
  required: PropTypes.bool,
  /** Style for label */
  big: PropTypes.bool,
  /** Aria attribute to make radio input focusable */
  tabIndex: PropTypes.number,
  /** Used for styling; true - inline; false - block */
  inline: PropTypes.bool,
  /** Is this disabled? */
  disabled: PropTypes.bool,
}

export default RadioButton
