import PropTypes from 'prop-types'
import React from 'react'
import Icon, { icons } from '../Icons'
import styles from './socialShareIcons.less'

/** Use this component where ever we show social share icons */
const renderSocialMediaLink = (href, onClick, icon, size, srOnlyText) => (
  <a href={href} onClick={onClick} aria-label={srOnlyText} className={styles.socialIcon}>
    <Icon icon={icon} className={styles.iconColor} size={size} />
  </a>
)

const SocialIcons = ({ className, url, children, twitterHandle, body }) => {
  const FBurl = `https://www.facebook.com/sharer/sharer.php?u=${url}`
  const LinkedInUrl = `https://www.linkedin.com/shareArticle?mini=true&url=${url}`
  const TwitterUrl = `https://twitter.com/share?url=${url}&text=${body}${
    twitterHandle ? `&via=${twitterHandle.substring(1)}` : ''
  }`
  const MailTo = `mailto:?subject=${body}&body=${url}`

  const wLeft = window.screenLeft ? window.screenLeft : window.screenX
  const width = wLeft + window.innerWidth / 2 || document.body.clientWidth
  const left = width - 600 / 2

  const popUpHandler = (targetUrl, features) => () =>
    window.open ? window.open(targetUrl, '', features) : false

  const popUpFb = popUpHandler(FBurl, `height=200,width=600,top=200,left=${left}`)
  const popUpTwitter = popUpHandler(
    TwitterUrl,
    `menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=450,width=600,top=200,left=${left}`
  )

  const popUpLinkedIn = popUpHandler(
    LinkedInUrl,
    `menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600,top=200,left=${left}`
  )

  return (
    <div className={className}>
      {renderSocialMediaLink('#facebook', popUpFb, icons.FACEBOOK, 24, 'Share via Facebook')}
      {renderSocialMediaLink('#twitter', popUpTwitter, icons.TWITTER, 24, 'Share via Twitter')}
      {renderSocialMediaLink('#linkedin', popUpLinkedIn, icons.LINKEDIN, 17, 'Share via LinkedIn')}
      {renderSocialMediaLink(MailTo, () => {}, icons.MAIL, 18, 'Share via Email')}
      {children}
    </div>
  )
}

SocialIcons.defaultProps = {
  className: styles.socialIconsContainer,
  children: null,
  twitterHandle: null,
}

SocialIcons.propTypes = {
  body: PropTypes.string.isRequired,
  url: PropTypes.string.isRequired,
  className: PropTypes.string,
  children: PropTypes.node,
  twitterHandle: PropTypes.string,
}

export default SocialIcons
