import PropTypes from 'prop-types'

export const inputShape = {
  /** The placeholder on the input */
  placeholder: PropTypes.string,
  /** The label on the input */
  label: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  /** Is the label a form group heading */
  isFormGroupHeading: PropTypes.bool,
  /** Called on Change */
  onChange: PropTypes.func,
  /** The value of the input */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.shape({}), PropTypes.number]),
  /** Is the input *required? */
  required: PropTypes.bool,
  /** Class passed to label */
  labelClass: PropTypes.string,
  /** Class passed to container div */
  containerClass: PropTypes.string,
  /** Can you type in the input? */
  disabled: PropTypes.bool,
  /** Is display inline-block? */
  inline: PropTypes.bool,
  /** Error message displayed under input */
  error: PropTypes.oneOfType([PropTypes.string, PropTypes.func, PropTypes.bool]),
  /** Descriptive text displayed under input */
  description: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
  /** The input of the id */
  id: PropTypes.string,
  /** The input type attribute value */
  type: PropTypes.string,
  /** Function called when input is in focus and specified key is pressed */
  onKeyDown: PropTypes.func,
  /** Allows parent components to use ref */
  handleRef: PropTypes.oneOfType([PropTypes.shape({}), PropTypes.func]),
  /** Is this part of a form group and the first child */
  inputGroupFirst: PropTypes.bool,
  /** Is this part of a form group and the last child */
  inputGroupLast: PropTypes.bool,
  /** Custom input width */
  inputWidth: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
}

export const inputDefaultProps = {
  label: null,
  onChange: null,
  value: undefined,
  required: false,
  labelClass: undefined,
  isFormGroupHeading: false,
  containerClass: undefined,
  disabled: false,
  inline: false,
  error: undefined,
  description: undefined,
  id: null,
  type: '',
  placeholder: '',
  onKeyDown: undefined,
  handleRef: undefined,
  inputGroupFirst: false,
  inputGroupLast: false,
  inputWidth: null,
}

export const limitCountProps = {
  updateCountLimit: PropTypes.func,
  updateCountType: PropTypes.func,
  countLimit: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  countType: PropTypes.string,
}

export const limitCountDefaultProps = {
  updateCountLimit: () => null,
  updateCountType: () => null,
  countLimit: undefined,
  countType: 'characters',
}

export const optionsShape = {
  /** Is the form required */
  isRequired: PropTypes.bool,
  /** Is the form blind */
  blindReview: PropTypes.bool,
  /** Is the form internal? */
  internalOnly: PropTypes.bool,
  /** Is the form using Auto Label? */
  autoLabel: PropTypes.bool,
  /** Is branching enabled */
  enableBranching: PropTypes.bool,
  /** Is branching enabled */
  allowRichTextEditing: PropTypes.bool,
  /** Is the optionList rendered inline */
  inline: PropTypes.bool,
}

export const optionsDefaultShape = {
  isRequired: null,
  isRequiredDisabled: false,
  blindReview: null,
  internalOnly: null,
  autoLabel: null,
  enableBranching: null,
  allowRichTextEditing: null,
  inline: null,
}

export const errorMessageDefaultShape = {
  message: null,
  label: null,
}

export const errorMessageShape = {
  /** id of input this is attached to */
  id: PropTypes.string.isRequired,
  /** String or node error message */
  message: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  /** String passed to the message function */
  label: PropTypes.string,
}
