import moment from 'moment'

/** @description Format a date to MM/DD/YYYY
 * @param {string} date String that is a valid date format
 * @return {object} Moment date object
 */
export const convertToMomentObject = date => {
  return moment(date)
}

/** @description Format a date to MM/DD/YYYY
 * @param {string} date String that is a valid date format
 * @return {string} Formatted date string
 */
export const formatDate = (date, format = 'MM/DD/YYYY') => {
  return moment(date, format).format(format)
}

/** @description Is the date after a specific date?
 * @param {string} date String that is a valid date format
 * @param {string} dateToCompare String that is a valid date format
 * @enum {string} [increment] the granularity of what you want to compare e.g. year month week isoWeek day hour minute second
 * @return {boolean}
 */
export const isAfter = (date, dateToCompare, increment) =>
  moment(date).isAfter(dateToCompare, increment)

/** @description Is the date before a specific date?
 * @param {string} date String that is a valid date format
 * @param {number} dateToCompare String that is a valid date format
 * @param {string} increment the granularity of what you want to compare
 * @return {boolean}
 */
export const isBefore = (date, dateToCompare = moment(), increment = 'day') =>
  moment(date).isBefore(dateToCompare, increment)

/**
 * Get now
 * @param {string} format - passed to momemnts format option
 * @return {string}
 */
export const now = (format = 'lll') => formatDate(Date.now(), format)

/** @description Determines if a date is valid
 * @param {string} date String that is a valid date format
 * @param {string} format Specific format date should match (optional)
 * @param {boolean} strict Enforce stricrt validation (optional) defaults to true
 * @return {boolean}
 */
export const isValidDate = (date, format = 'MM/DD/YYYY', strict = true) => {
  return moment(date, format, strict).isValid()
}
