import { useEffect, useState } from 'react'

export const templateConcat = (strings, expressions) =>
  strings.reduce((prevValue, currentValue, index) => {
    const expressionValue = expressions[index]
    const expressionType = typeof expressionValue
    if (expressionValue && expressionType !== 'string' && expressionType !== 'number') {
      throw new Error(`localize can only translate strings not ${expressionType}`)
    }
    if (expressionValue) {
      return `${prevValue}${currentValue}${expressionValue}`
    }
    return `${prevValue}${currentValue}`
  }, '')

export const useLocalize = (strings, ...expressions) => {
  const [translatedText, setTranslatedText] = useState(templateConcat(strings, expressions))
  useEffect(() => {
    const shouldLocalize = window.Localize && window.Localize.loaded
    const currentLanguage = shouldLocalize ? window.Localize.getLanguage() : 'en'
    const updateTranslation = lang => {
      if (lang.to === 'en') setTranslatedText(templateConcat(strings, expressions))
      else
        setTranslatedText(
          templateConcat(
            strings.map(value => (value !== '' ? window.Localize.translate(value) : value)),
            expressions
          )
        )
    }
    if (shouldLocalize) window.Localize.on('setLanguage', updateTranslation)
    updateTranslation({ to: currentLanguage })
    return () => shouldLocalize && window.Localize.off('setLanguage', updateTranslation)
  }, [translatedText, strings, expressions])
  return translatedText
}

export const useLocalizeAll = (strings, ...expressions) => {
  const translation = templateConcat(strings, expressions)
  const [translatedText, setTranslatedText] = useState(translation)
  useEffect(() => {
    const shouldLocalize = window.Localize && window.Localize.loaded
    const currentLanguage = shouldLocalize ? window.Localize.getLanguage() : 'en'
    const updateTranslation = lang => {
      if (lang.to === 'en') setTranslatedText(templateConcat(strings, expressions))
      else
        setTranslatedText(
          templateConcat(
            strings.map(value => (value !== '' ? window.Localize.translate(value) : value)),
            expressions.map(value =>
              value !== '' && typeof value !== 'number' ? window.Localize.translate(value) : value
            )
          )
        )
    }
    if (shouldLocalize) window.Localize.on('setLanguage', updateTranslation)
    updateTranslation({ to: currentLanguage })
    return () => shouldLocalize && window.Localize.off('setLanguage', updateTranslation)
  }, [translatedText, setTranslatedText, strings, expressions])
  return translatedText
}
