/**
 * Utility to prevent tabbing outside of an overlay.
 */
export default class OverlayTabManager {
  constructor({ rootElement, focusFirst = false, focusLast = false }) {
    this.rootElement = rootElement
    this.removeListeners = null
    this.focusFirst = focusFirst
    this.focusLast = focusLast
  }

  startCapture() {
    this.endCapture()

    const inputs = this.rootElement.querySelectorAll('input, button, a, [role="menu"]')

    if (!inputs.length) {
      return
    }

    const firstInput = inputs[0]
    const lastInput = inputs[inputs.length - 1]

    if (this.focusFirst) {
      firstInput.focus()
    }

    if (this.focusLast) {
      lastInput.focus()
    }

    const firstInputListener = e => {
      if (e.keyCode === 9 && e.shiftKey) {
        e.preventDefault()
        lastInput.focus()
      }
    }
    firstInput.addEventListener('keydown', firstInputListener.bind(this))

    const lastInputListener = e => {
      if (e.keyCode === 9 && !e.shiftKey) {
        e.preventDefault()
        firstInput.focus()
      }
    }
    lastInput.addEventListener('keydown', lastInputListener.bind(this))

    this.removeListeners = () => {
      firstInput.removeEventListener('keydown', firstInputListener.bind(this))
      lastInput.removeEventListener('keydown', lastInputListener.bind(this))
    }
  }

  endCapture() {
    if (this.removeListeners) {
      this.removeListeners()
      this.removeListeners = null
    }
  }

  dispose() {
    this.endCapture()
  }
}
